#!/usr/bin/env perl
# $v =~ // && grep { index() }
use strict;
use warnings;
use Benchmark ':all';
use Test::More 'no_plan';

my $Fa = 'Delivery failed, blacklisted by rbl';
my $Re = qr{(?>
     access[ ]denied[.][ ]ip[ ]name[ ]lookup[ ]failed
    |bad[ ]sender[ ]ip[ ]address
    |the[ ](?:email|domain|ip).+[ ]is[ ]blacklisted
    |too[ ]many[ ]spams[ ]from[ ]your[ ]ip
    |unresolvable[ ]relay[ ]host[ ]name
    |blacklisted[ ]by
    )
}x;
my $Ar = [
    'access denied. ip name lookup failed',
    'bad sender ip address',
    ' is blacklisted',
    'too many spams from your ip',
    'unresolvable relay host name',
    'blacklisted by',
];

sub regex { return 1 if $Fa =~ $Re}
sub grep1 { return 1 if grep { index($Fa, $_) > -1 } @$Ar}

is regex(), 1;
is grep1(), 1;

printf("Perl %s on %s\n%s\n", $^V, $^O, '-' x 50);
cmpthese(6e5, {
        '=~ //'   => sub { regex() },
        'grep @v' => sub { grep1() },
    }
);

eval { require Devel::Size };
unless( $@ ) {
    printf("\n");
    printf("%s %6d bytes\n", '$Re = qr{...}', Devel::Size::total_size($Re));
    printf("%s %6d bytes\n", '$Ar = [ ... ]', Devel::Size::total_size($Ar));
}

__END__

Perl v5.18.2 on darwin
--------------------------------------------------
             Rate   =~ // grep @v
=~ //    387097/s      --    -63%
grep @v 1052632/s    172%      --

Perl v5.22.1 on darwin
--------------------------------------------------
             Rate   =~ // grep @v
=~ //    476190/s      --    -56%
grep @v 1090909/s    129%      --

Perl v5.28.1 on darwin
--------------------------------------------------
             Rate   =~ // grep @v
=~ //    545455/s      --    -63%
grep @v 1463415/s    168%      --

