#!/usr/bin/env perl
# /\./ vs. /[.]/ vs. /\Q.\E/
use strict;
use warnings;
use Benchmark ':all';
use Test::More 'no_plan';

my $Email = 'kijitora@neko.nyaan.jp';

sub bs { return 1 if $Email =~ /neko\.nyaan\.jp/ }
sub cc { return 1 if $Email =~ /neko[.]nyaan[.]jp/ }
sub qe { return 1 if $Email =~ /\Qneko.nyaan.jp\E/ }

is bs, 1;
is cc, 1;
is qe, 1;

printf("Perl %s on %s\n%s\n", $^V, $^O, '-' x 50);
cmpthese(6e6, {
        '\.'   => sub { bs() },
        '[.]'  => sub { cc() },
        '\Q\E' => sub { qe() },
    }
);

__END__

Perl v5.18.2 on darwin
--------------------------------------------------
          Rate  [.] \Q\E   \.
[.]  4137931/s   --  -0%  -4%
\Q\E 4137931/s   0%   --  -4%
\.   4316547/s   4%   4%   --

Perl v5.22.1 on darwin
--------------------------------------------------
          Rate   \.  [.] \Q\E
\.   4137931/s   --  -2%  -4%
[.]  4225352/s   2%   --  -2%
\Q\E 4316547/s   4%   2%   --

Perl v5.28.1 on darwin
--------------------------------------------------
          Rate   \.  [.] \Q\E
\.   5042017/s   --  -3%  -4%
[.]  5217391/s   3%   --  -1%
\Q\E 5263158/s   4%   1%   --

