#!/usr/bin/env perl
# for vs. foreach vs. while vs. grep
use strict;
use warnings;
use Benchmark ':all';
use Test::More 'no_plan';

sub loop1f {
    my $v = 0;
    my @p = (1..256);
    for( my $e = 0; $e < 256; $e++ ) {
        $v++ if $p[$e] % 2 == 0;
    }
    return $v;
}

sub loop2e {
    my $v = 0;
    my @p = (1..256);
    foreach my $e ( @p ) {
        $v++ if $e % 2 == 0;
    }
    return $v;
}

sub loop3w {
    my $v = 0;
    my @p = (1..256);
    while( my $e = shift @p ) {
        $v++ if $e % 2 == 0;
    }
    return $v;
}

sub loop4g {
    my $v = 0;
    my @p = (1..256);
    $v = grep { $_ % 2 == 0 } @p;
    return $v;
}

is loop1f(), 128;
is loop2e(), 128;
is loop3w(), 128;
is loop4g(), 128;

printf("Perl %s on %s\n%s\n", $^V, $^O, '-' x 50);
cmpthese(1e5, {
        'for'     => sub { loop1f() },
        'foreach' => sub { loop2e() },
        'while'   => sub { loop3w() },
        'grep'    => sub { loop4g() },
    }
);

__END__

Perl v5.18.2 on darwin
--------------------------------------------------
           Rate   while     for foreach    grep
while   19417/s      --     -7%    -33%    -39%
for     20964/s      8%      --    -28%    -34%
foreach 29155/s     50%     39%      --     -8%
grep    31847/s     64%     52%      9%      --

Perl v5.22.1 on darwin
--------------------------------------------------
           Rate   while     for foreach    grep
while   20284/s      --    -17%    -33%    -43%
for     24450/s     21%      --    -19%    -32%
foreach 30303/s     49%     24%      --    -15%
grep    35714/s     76%     46%     18%      --

Perl v5.28.1 on darwin
--------------------------------------------------
           Rate   while     for    grep foreach
while   23202/s      --    -21%    -38%    -38%
for     29326/s     26%      --    -21%    -22%
grep    37313/s     61%     27%      --     -1%
foreach 37594/s     62%     28%      1%      --

