#!/usr/bin/env perl
# grep {...} @v vs. exists $v{key}
use strict;
use warnings;
use Benchmark ':all';
use Test::More 'no_plan';

my $A = [1..1e2]; map { $_ = 'X-Neko-Nyaan-'.$_ } @$A;
my $H = { map { $_ => 1 } @$A };

sub usegrep {
    my $v = shift;
    return 1 if grep { $v eq $_ } @$A;
}

sub hashkey {
    my $v = shift;
    return 1 if exists $H->{ $v };
}

is usegrep('X-Neko-Nyaan-25'), 1;
is hashkey('X-Neko-Nyaan-25'), 1;

printf("Perl %s on %s\n%s\n", $^V, $^O, '-' x 50);
cmpthese(6e6, {
        'grep{}' => sub { usegrep('X-Neko-Nyaan-53') },
        'exists' => sub { hashkey('X-Neko-Nyaan-53') },
    }
);

eval { require Devel::Size };
unless( $@ ) {
    printf("\n");
    printf("%s %6d bytes\n", '$H = {...}', Devel::Size::total_size($H));
    printf("%s %6d bytes\n", '$A = [...]', Devel::Size::total_size($A));
}

__END__

Perl v5.18.2 on darwin
--------------------------------------------------
            Rate grep{} exists
grep{}  162602/s     --   -95%
exists 3157895/s  1842%     --

Perl v5.22.1 on darwin
--------------------------------------------------
            Rate grep{} exists
grep{}  153413/s     --   -95%
exists 3141361/s  1948%     --

Perl v5.28.1 on darwin
--------------------------------------------------
            Rate grep{} exists
grep{}  157192/s     --   -96%
exists 3636364/s  2213%     --

