#!/usr/bin/env perl
# grep {...} @v vs. exists $v{key}
use strict;
use warnings;
use Benchmark ':all';
use Test::More 'no_plan';

my $A = ['From', 'Reply-To', 'To'];
my $H = {'From' => 1, 'Reply-To' => 1, 'To' => 1};

sub usegrep {
    my $v = shift;
    return 1 if grep { $v eq $_ } @$A;
}

sub hashkey {
    my $v = shift;
    return 1 if exists $H->{ $v };
}

is usegrep('Reply-To'), 1;
is hashkey('Reply-To'), 1;

printf("Perl %s on %s\n%s\n", $^V, $^O, '-' x 50);
cmpthese(6e6, {
        'grep{}' => sub { usegrep('Reply-To') },
        'exists' => sub { hashkey('Reply-To') },
    }
);

eval { require Devel::Size };
unless( $@ ) {
    printf("\n");
    printf("%s %6d bytes\n", '$H = {...}', Devel::Size::total_size($H));
    printf("%s %6d bytes\n", '$A = [...]', Devel::Size::total_size($A));
}

__END__

Perl v5.18.2 on darwin
--------------------------------------------------
            Rate grep{} exists
grep{} 1898734/s     --   -41%
exists 3191489/s    68%     --

Perl v5.22.1 on darwin
--------------------------------------------------
            Rate grep{} exists
grep{} 1898734/s     --   -44%
exists 3370787/s    78%     --

Perl v5.28.1 on darwin
--------------------------------------------------
            Rate grep{} exists
grep{} 2166065/s     --   -44%
exists 3896104/s    80%     --

