#!/usr/bin/env perl
# /\A<.*@.*>\z/ vs. index() x 2, substr()
use strict;
use warnings;
use Benchmark ':all';
use Test::More 'no_plan';

my $Email = '<neko@nyaan.jp>';

sub regexp { return 1 if $Email =~ /\A<.*@.*>\z/ }
sub indexs {
    if( index($Email, '<') == 0 &&
        index($Email, '@') > -1 &&
        substr($Email, -1, 1) eq '>' ) {

        return 1 
    }
}

is regexp, 1;
is indexs, 1;

printf("Perl %s on %s\n%s\n", $^V, $^O, '-' x 50);
cmpthese(6e6, {
        '/\A<.*@.*>\z/' => sub { regexp() },
        'index,substr'  => sub { indexs() },
    }
);

__END__

Perl v5.18.2 on darwin
--------------------------------------------------
                   Rate /\A<.*@.*>\z/  index,substr
/\A<.*@.*>\z/ 1759531/s            --          -36%
index,substr  2752294/s           56%            --

Perl v5.22.1 on darwin
--------------------------------------------------
                   Rate /\A<.*@.*>\z/  index,substr
/\A<.*@.*>\z/ 1775148/s            --          -40%
index,substr  2970297/s           67%            --

Perl v5.28.1 on darwin
--------------------------------------------------
                   Rate /\A<.*@.*>\z/  index,substr
/\A<.*@.*>\z/ 2068966/s            --          -43%
index,substr  3658537/s           77%            --

