#!/usr/bin/env perl
# /A/i vs. /[Mm]/ vs. lc($v)
use strict;
use warnings;
use Benchmark ':all';
use Test::More 'no_plan';

my $Text = 'Mailer-Daemon';

sub regex1 { return 1 if $Text =~ /\Amailer-daemon\z/i }
sub regex2 { return 1 if $Text =~ /\A[Mm]ailer-[Dd]aemon\z/ }
sub lcfunc { return 1 if lc $Text eq 'mailer-daemon' }

is regex1, 1;
is regex2, 1;
is lcfunc, 1;

printf("Perl %s on %s\n%s\n", $^V, $^O, '-' x 50);
cmpthese(6e6, {
        '=~ /.../i' => sub { regex1() },
        '=~ /[Mm]/' => sub { regex2() },
        'lc($v) eq' => sub { lcfunc() },
    }
);

__END__

Perl v5.18.2 on darwin
--------------------------------------------------
               Rate =~ /[Mm]/ =~ /.../i lc($v) eq
=~ /[Mm]/ 2150538/s        --      -25%      -53%
=~ /.../i 2870813/s       33%        --      -37%
lc($v) eq 4580153/s      113%       60%        --

Perl v5.22.1 on darwin
--------------------------------------------------
               Rate =~ /[Mm]/ =~ /.../i lc($v) eq
=~ /[Mm]/ 2390438/s        --      -16%      -46%
=~ /.../i 2830189/s       18%        --      -36%
lc($v) eq 4444444/s       86%       57%        --

Perl v5.28.1 on darwin
--------------------------------------------------
               Rate =~ /.../i =~ /[Mm]/ lc($v) eq
=~ /.../i 2752294/s        --       -4%      -57%
=~ /[Mm]/ 2857143/s        4%        --      -56%
lc($v) eq 6451613/s      134%      126%        --

