#!/usr/bin/env perl
# s/// vs. y///
use strict;
use warnings;
use Benchmark ':all';
use Test::More 'no_plan';

my $Email = '<neko@nyaan.jp>';

sub ss {
    my $v = shift;
    $v =~ s/[<>]//g;
    return $v;
}

sub yy {
    my $v = shift;
    $v =~ y/<>//d;
    return $v;
}

is ss($Email), 'neko@nyaan.jp';
is yy($Email), 'neko@nyaan.jp';

printf("Perl %s on %s\n%s\n", $^V, $^O, '-' x 50);
cmpthese(6e6, {
        's///' => sub { ss($Email) },
        'y///' => sub { yy($Email) },
    }
);

__END__

Perl v5.18.2 on darwin
--------------------------------------------------
          Rate s/// y///
s/// 1348315/s   -- -55%
y/// 3000000/s 122%   --

Perl v5.22.1 on darwin
--------------------------------------------------
          Rate s/// y///
s/// 1372998/s   -- -59%
y/// 3351955/s 144%   --

Perl v5.28.1 on darwin
--------------------------------------------------
          Rate s/// y///
s///  895522/s   -- -78%
y/// 4137931/s 362%   --

